# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt

class UserNotificationSettingsResponse(BaseModel):
    """
    UserNotificationSettingsResponse
    """
    id: Optional[StrictInt] = None
    user_id: StrictInt = Field(...)
    receive_email_notifications: Optional[StrictBool] = False
    receive_in_app_notifications: Optional[StrictBool] = True
    __properties = ["id", "user_id", "receive_email_notifications", "receive_in_app_notifications"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UserNotificationSettingsResponse:
        """Create an instance of UserNotificationSettingsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UserNotificationSettingsResponse:
        """Create an instance of UserNotificationSettingsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UserNotificationSettingsResponse.parse_obj(obj)

        _obj = UserNotificationSettingsResponse.parse_obj({
            "id": obj.get("id"),
            "user_id": obj.get("user_id"),
            "receive_email_notifications": obj.get("receive_email_notifications") if obj.get("receive_email_notifications") is not None else False,
            "receive_in_app_notifications": obj.get("receive_in_app_notifications") if obj.get("receive_in_app_notifications") is not None else True
        })
        return _obj


