# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector.api.templates_api import TemplatesApi  # noqa: E501


class TestTemplatesApi(unittest.IsolatedAsyncioTestCase):
    """TemplatesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = TemplatesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_templates_delete_portal_override(self) -> None:
        """Test case for templates_delete_portal_override

        Delete override  # noqa: E501
        """
        pass

    async def test_templates_get_contact_footer(self) -> None:
        """Test case for templates_get_contact_footer

        Get contact info footer  # noqa: E501
        """
        pass

    async def test_templates_get_overridable_source_types(self) -> None:
        """Test case for templates_get_overridable_source_types

        Get all overridable source types  # noqa: E501
        """
        pass

    async def test_templates_get_portal_template(self) -> None:
        """Test case for templates_get_portal_template

        Get specific template for portal  # noqa: E501
        """
        pass

    async def test_templates_get_portal_templates(self) -> None:
        """Test case for templates_get_portal_templates

        Get all templates for portal  # noqa: E501
        """
        pass

    async def test_templates_get_templates(self) -> None:
        """Test case for templates_get_templates

        Get raw templates  # noqa: E501
        """
        pass

    async def test_templates_reset_contact_footer(self) -> None:
        """Test case for templates_reset_contact_footer

        Reset contact info footer  # noqa: E501
        """
        pass

    async def test_templates_upsert_contact_footer(self) -> None:
        """Test case for templates_upsert_contact_footer

        Set contact info footer  # noqa: E501
        """
        pass

    async def test_templates_upsert_portal_override(self) -> None:
        """Test case for templates_upsert_portal_override

        Create or update override  # noqa: E501
        """
        pass

    async def test_templates_upsert_portal_overrides_batch(self) -> None:
        """Test case for templates_upsert_portal_overrides_batch

        Batch create or update overrides  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
